==> jc-1.4.0.tar.gz: soot/G.h <==
// public class soot.G

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class 6ac5bee50bbabb71 soot_Singletons

// header file dependencies
// @dep_header soot_Singletons

#include "soot/Singletons.h"

#ifndef _JC_soot_G_H_
#define _JC_soot_G_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_G$object;
struct _jc_soot_Timer$object;
struct _jc_soot_coffi_Utf8__5fEnumeration$object;
struct _jc_soot_jimple_spark_sets_P2SetFactory$object;
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object;
struct _jc_soot_jimple_toolkits_pointer_util_NativeHelper$object;

// Typedefs
typedef struct _jc_soot_G$sub_refs	_jc_soot_G$sub_refs;
typedef struct _jc_soot_G$sub_nonrefs	_jc_soot_G$sub_nonrefs;
typedef struct _jc_soot_G$refs	_jc_soot_G$refs;
typedef struct _jc_soot_G$nonrefs	_jc_soot_G$nonrefs;
typedef struct _jc_soot_G$object	_jc_soot_G$object;

typedef struct _jc_soot_G$fields_struct	_jc_soot_G$fields_struct;
typedef const struct _jc_soot_G$vmethods	_jc_soot_G$vmethods;
typedef const struct _jc_soot_G$vtable	_jc_soot_G$vtable;
typedef const struct _jc_soot_G$vtype	_jc_soot_G$vtype;

// Class fields structure
struct _jc_soot_G$fields_struct {
	struct _jc_soot_G$object	*instance;
};
extern _jc_soot_G$fields_struct _jc_soot_G$class_fields;

// Constructors
extern void _jc_soot_G$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_G$object *);

// Static methods
extern void _jc_soot_G$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_soot_G$method$reset$229a80b3e8394a0f(_jc_env *);
extern struct _jc_soot_G$object *_jc_soot_G$method$v$50a1f1a8e8188185(_jc_env *);

// Virtual methods structure
struct _jc_soot_G$vmethods {
};

// Vtable
struct _jc_soot_G$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Singletons$vmethods	soot_Singletons;
	_jc_soot_G$vmethods	soot_G;
};

// Vtype
struct _jc_soot_G$vtype {
	_jc_type			type;
	_jc_soot_G$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_G$sub_refs {
	struct _jc_java_io_PrintStream$object	*out;
	struct _jc_soot_coffi_Utf8__5fEnumeration$object	*coffi__5fCONSTANT__5fUtf8__5finfo__5fe1;
	struct _jc_soot_coffi_Utf8__5fEnumeration$object	*coffi__5fCONSTANT__5fUtf8__5finfo__5fe2;
	struct _jc_java_util_HashMap$object	*SETBasicBlock__5fbinding;
	struct _jc_soot_jimple_toolkits_pointer_util_NativeHelper$object	*NativeHelper__5fhelper;
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object	*newSetFactory;
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object	*oldSetFactory;
	struct _jc_java_util_HashMap$object	*Parm__5fpairToElement;
	struct _jc_java_util_HashMap$object	*MethodPAG__5fmethodToPag;
	struct _jc_object	*MethodRWSet__5fallGlobals;
	struct _jc_object	*MethodRWSet__5fallFields;
	struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object	*Union__5ffactory;
	struct _jc_java_util_HashMap$object	*Array2ndDimensionSymbol__5fpool;
	struct _jc_object	*AbstractUnit__5fallMapToUnnamed;
	struct _jc_object	*Timer__5foutstandingTimers;
	struct _jc_soot_Timer$object	*Timer__5fforcedGarbageCollectionTimer;
	struct _jc_object	*ClassHierarchy__5fclassHierarchyMap;
	struct _jc_object	*MethodContext__5fmap;
};

// Reference instance fields (object)
struct _jc_soot_G$refs {
    _jc_soot_G$sub_refs	soot_G;
    _jc_soot_Singletons$sub_refs	soot_Singletons;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_G$sub_nonrefs {
	jlong	coffi__5fBasicBlock__5fids;
	jint	SETNodeLabel__5funiqueId;
	jboolean	ASTAnalysis__5fmodified;
	jint	SparkNativeHelper__5ftempVar;
	jboolean	PointsToSetInternal__5fwarnedAlready;
	jint	GeneralConstObject__5fcounter;
	jboolean	Timer__5fisGarbageCollecting;
	jint	Timer__5fcount;
	jboolean	isJ2ME;
};

// Non-reference instance fields (object)
struct _jc_soot_G$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Singletons$sub_nonrefs	soot_Singletons;
    _jc_soot_G$sub_nonrefs	soot_G;
};

// Object instance structure
struct _jc_soot_G$object {
	_jc_soot_G$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_G$vtype	*vtype;
	_jc_soot_G$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_G$vtype _jc_soot_G$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_G, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_G$class_object;

#endif	/* _JC_soot_G_H_ */

==> jc-1.4.6.tar.gz: soot/G.h <==
// public class soot.G

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class 6ac5bee50bbabb71 soot_Singletons

// header file dependencies
// @dep_header soot_Singletons

#include "soot/Singletons.h"

#ifndef _JC_soot_G_H_
#define _JC_soot_G_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_G$object;
struct _jc_soot_Timer$object;
struct _jc_soot_coffi_Utf8__5fEnumeration$object;
struct _jc_soot_jimple_spark_sets_P2SetFactory$object;
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object;
struct _jc_soot_jimple_toolkits_pointer_util_NativeHelper$object;

// Typedefs
typedef struct _jc_soot_G$sub_refs	_jc_soot_G$sub_refs;
typedef struct _jc_soot_G$sub_nonrefs	_jc_soot_G$sub_nonrefs;
typedef struct _jc_soot_G$refs	_jc_soot_G$refs;
typedef struct _jc_soot_G$nonrefs	_jc_soot_G$nonrefs;
typedef struct _jc_soot_G$object	_jc_soot_G$object;

typedef struct _jc_soot_G$fields_struct	_jc_soot_G$fields_struct;
typedef const struct _jc_soot_G$vmethods	_jc_soot_G$vmethods;
typedef const struct _jc_soot_G$vtable	_jc_soot_G$vtable;
typedef const struct _jc_soot_G$vtype	_jc_soot_G$vtype;

// Class fields structure
struct _jc_soot_G$fields_struct {
	struct _jc_soot_G$object	*instance;
};
extern _jc_soot_G$fields_struct _jc_soot_G$class_fields;

// Constructors
extern void _jc_soot_G$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_G$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_G$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_soot_G$method$reset$229a80b3e8394a0f(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_G$object *_jc_soot_G$method$v$50a1f1a8e8188185(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_G$vmethods {
};

// Vtable
struct _jc_soot_G$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Singletons$vmethods	soot_Singletons;
	_jc_soot_G$vmethods	soot_G;
};

// Vtype
struct _jc_soot_G$vtype {
	_jc_type			type;
	_jc_soot_G$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_G$sub_refs {
	struct _jc_java_io_PrintStream$object	*out;
	struct _jc_soot_coffi_Utf8__5fEnumeration$object	*coffi__5fCONSTANT__5fUtf8__5finfo__5fe1;
	struct _jc_soot_coffi_Utf8__5fEnumeration$object	*coffi__5fCONSTANT__5fUtf8__5finfo__5fe2;
	struct _jc_java_util_HashMap$object	*SETBasicBlock__5fbinding;
	struct _jc_soot_jimple_toolkits_pointer_util_NativeHelper$object	*NativeHelper__5fhelper;
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object	*newSetFactory;
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object	*oldSetFactory;
	struct _jc_java_util_HashMap$object	*Parm__5fpairToElement;
	struct _jc_java_util_HashMap$object	*MethodPAG__5fmethodToPag;
	struct _jc_object	*MethodRWSet__5fallGlobals;
	struct _jc_object	*MethodRWSet__5fallFields;
	struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object	*Union__5ffactory;
	struct _jc_java_util_HashMap$object	*Array2ndDimensionSymbol__5fpool;
	struct _jc_object	*AbstractUnit__5fallMapToUnnamed;
	struct _jc_object	*Timer__5foutstandingTimers;
	struct _jc_soot_Timer$object	*Timer__5fforcedGarbageCollectionTimer;
	struct _jc_object	*ClassHierarchy__5fclassHierarchyMap;
	struct _jc_object	*MethodContext__5fmap;
};

// Reference instance fields (object)
struct _jc_soot_G$refs {
    _jc_soot_G$sub_refs	soot_G;
    _jc_soot_Singletons$sub_refs	soot_Singletons;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_G$sub_nonrefs {
	jlong	coffi__5fBasicBlock__5fids;
	jint	SETNodeLabel__5funiqueId;
	jboolean	ASTAnalysis__5fmodified;
	jint	SparkNativeHelper__5ftempVar;
	jboolean	PointsToSetInternal__5fwarnedAlready;
	jint	GeneralConstObject__5fcounter;
	jboolean	Timer__5fisGarbageCollecting;
	jint	Timer__5fcount;
	jboolean	isJ2ME;
};

// Non-reference instance fields (object)
struct _jc_soot_G$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Singletons$sub_nonrefs	soot_Singletons;
    _jc_soot_G$sub_nonrefs	soot_G;
};

// Object instance structure
struct _jc_soot_G$object {
	_jc_soot_G$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_G$vtype	*vtype;
	_jc_soot_G$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_G$vtype _jc_soot_G$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_G, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_G$class_object;

#endif	/* _JC_soot_G_H_ */
